######################################################################################
##########################  ONE-WAY ANOVA  ###########################################
######################################################################################

#One-way ANOVA compare levels (i.e. groups) of a single factor on a single continuous variable

#Example - comparing tomato growth rate from various fertilizer treatments
tomato <- read.table("oneway.anova_data.txt", header = TRUE)

#Make some boxplots and see if there is any constant mean in the visualizeation
boxplot(tomato, xlab="Treatment", ylab="Tomato Production (kg)", col="blue")

#To run the ANOVA, we need a table that just has the means of each group
#Let's do that in Excel and read in the new file
#Let's try doing pairwise comparisons
#Now let's look at the means and see if there are differences
mean(tomato$control)
mean(tomato$treatment1)
mean(tomato$treatment2)
mean(tomato$treatment3)
mean(tomato$treatment4)

#Check if our data is normally distributed
shapiro.test(tomato$control)
shapiro.test(tomato$treatment1)
shapiro.test(tomato$treatment2)
shapiro.test(tomato$treatment3)
shapiro.test(tomato$treatment4)

#Run a one-way anova for the whole group
production <- data.frame(Treatment = c(rep("Control",50),rep("Treatment1",50),rep("Treatment2",50),rep("Treatment3",50),rep("Treatment4",50)),
                         Growth = c(tomato$control,tomato$treatment1,tomato$treatment2,tomato$treatment3,tomato$treatment4))

anova.gr<-aov(Growth~Treatment,data=production)
summary(anova.gr)


#Since it's not normally distributed, run a Kruskal-Wallace test
kruskal.test(Growth~Treatment, data = production)

#Now that we know that a difference exists, run individual comparisons
#A Tukey test is a common method
TukeyHSD(anova.gr)

#Try the Duncan's range test
# install.packages("agricolae")
# library(agricolae)
# duncan.test(anova.gr,"Treatment",group = T, console = T)


######################################################################################
##########################  TWO-WAY ANOVA  ###########################################
######################################################################################

#Two-way ANOVAs compare levels of two or more factors for the mean differences on a single continuous variable

#Example: Comparing activity of the enzyme mannose-6-phosphate isomerase (MPI) in mice 
#across genotype (ff, fs, ss) and sex (male, female)
activity <- read.table("twoway.anova_data.txt", header = TRUE)

#Make some boxplots
boxplot(Activity ~ Genotype, data = activity, xlab = "Genotype", ylab = "MPI Activity")
boxplot(Activity ~ Genotype:Sex, data = activity, xlab = "Genotype x Sex", ylab = "MPI Activity")

#Fit a linear model
model = lm(Activity ~ Sex + Genotype + Sex:Genotype, data=activity)



model.block = lm(Activity ~ Sex + Block, data = activity)





install.packages(car)
library(car)
#You can choose a number of different types of outputs
Anova(model, type="II")

#This options produces type 1 sum of squares
anova(model)

#This one produces r-squared, p-value, parameter estimates
summary(model)

######################################################################################
##########################      ANCOVA     ###########################################
######################################################################################

#ANCOVA, or Analysis of covariance, compares a single continuous response variable by both a factor AND
#A continuous independant variable

#Example: comparing pulse rate between species in response to temperature
ancova <- read.table("ancova_data.txt", header = TRUE)

#Plot to show differences between species across temperature
plot(x = ancova$Temp, y = ancova$Pulse, col = ancova$Species, pch = 16, xlab = "Temperature", ylab = "Pulse")
legend('bottomright',legend = levels(ancova$Species),col = 1:2,cex = 1,pch = 16)

#Make species a dummy variable
options(contrasts = c("contr.treatment", "contr.poly"))
contrasts(ancova$Species)

#Run a linear model with an interaction term
library(car)
model.1 = lm (Pulse ~ Temp + Species + Temp:Species, data = ancova)
anova(model.1)

# Anova(model.1, type="II")
summary(model.1)
#The interaction term is not significant
#This shows that the slopes are not different between species - 
#this means that the pulse does not vary with temperature differently between species

#Now include an interaction
model.2 = lm (Pulse ~ Temp + Species, data = ancova)
anova(model.2)
Anova(model.2, type="II")
summary(model.2)
#The species variable is significant
#This means that the intercept is different among species -
#this means that the pulse rate is different between species

#Let's plot the data with fitted lines
plot(x = ancova$Temp, y = ancova$Pulse, col = ancova$Species, pch = 16, xlab = "Temperature", ylab = "Pulse")
legend('bottomright',legend = levels(ancova$Species),col = 1:2, cex = 1,  pch = 16)
I.nought = coef(model.1)[1]
I1 = I.nought + 0
I2 = I.nought + coef(model.1)[3]
B  = coef(model.1)[2]
abline(I1, B, lty=1, lwd = 2, col = 1)
abline(I2, B, lty=1, lwd = 2, col = 2)

######################################################################################
##########################      MANOVA     ###########################################
######################################################################################

#MANOVA stands for multivariate analysis of variance
#MANOVA is an ANOVA with two or more continuous response variables

#You can perform both one-way and two-way MANOVAs, distinguished by the number of factor variables
#Example: Sepal length and petal length comparisons between iris species
data(iris)   #iris data is available in R

#Create vectors of sepal and petal length
sepl <- iris$Sepal.Length
petl <- iris$Petal.Length

#Run a MANOVA
res.man <- manova(cbind(Sepal.Length, Petal.Length) ~ Species, data = iris)
summary(res.man)            #Compares across both variables
summary.aov(res.man)        #Compares across each variable separately 

######################################################################################
##########################     MANCOVA     ###########################################
######################################################################################

#MANCOVA stands for multivariate analysis of covariance
#MANCOVA is an ANCOVA with 2 response variables, 1 factor, and 1 independant variable

#Example: Test score + income + level of education + hours studied
#In this example you are actually going to generate random data rather than bringing in a dataset
install.packages(mvtnorm)
library(mvtnorm)
subj <- factor(rep(c("a","b","c","d","e","f","g","h","i","j"),10))
x <- rnorm(100)
beta1 <- 1
beta2 <- -0.7
b1 <- rnorm(10,sd=5)
b2 <- rnorm(10,sd=2)
mu <- cbind(x * beta1  + b1[subj],x * beta2 + b2[subj])
Y <- t(apply(mu, 1, function(x) rmvnorm(1, x, matrix(c(6,3,3,4),2,2))))

#Fit the model & get results
fit <- manova(Y ~ x)
summary.manova(fit)
summary.aov(fit)

#Example 1
data("chickwts")
head(chickwts)

shapiro.test(chickwts$weight)

anova.model <- aov(weight~feed, data = chickwts)
summary(anova.model)

TukeyHSD(anova.model, ordered = TRUE)

#Example 2
data("ChickWeight")
head(ChickWeight)

shapiro.test(ChickWeight$weight)

aov <- lm(weight ~ Chick + Diet + Chick:Diet, data = ChickWeight)
anova(aov)
summary(aov)

#Example 3
aov2 <- lm(weight ~ Diet + Time + Diet:Time, data = ChickWeight)
anova(aov2)
