#########################################################################################
############################  LINEAR REGRESSION  ########################################
#########################################################################################
# require(stats); require(graphics)

#Read in student height and weight data
students <- read.table("lm_data.txt", header = TRUE)

#Plot each variable
hist(students$Height)
hist(students$Weight)

#Check for normality
shapiro.test(students$Weight)

#Plot the data against each other
plot(x = students$Height, y = students$Weight, 
     xlab = "Height", ylab = "Weight", pch = 16)

#Add a regression line to the map
abline(lm(students$Weight ~ students$Height), col = "red")

#Run the model
lm.mod = lm(students$Weight ~ students$Height)
summary(lm.mod)
anova(lm.mod)

#R2 is a value between 0 and 100%
#0% means that the model explains none of the variability of the response data around the mean
#100% means that they models explains everythingt
#The closer to 100%, the better your line fits the data
#What do you think?  Is it the same as we found in Excel?


#########################################################################################
###########################  MULTIPLE REGRESSION  #######################################
#########################################################################################
install.packages("psych")
library(psych)
install.packages("PerformanceAnalytics")
library(PerformanceAnalytics)
install.packages("rcompanion")
library(rcompanion)


#Multiple regression is the same as simple linear regression, 
#except there is more than one predictor variable (still one response variable)

#Create a simulation data from of the amount of carbs & protein 
#ingested by individuals, with their age and weight
calorie <- data.frame(
  carb = c(33,40,37,27,30,43,34,48,30,38,
           50,51,30,36,41,42,46,24,35,37),
  age	 = c(33,47,49,35,46,52,62,23,32,42,
           31,61,63,40,50,64,56,61,48,28),
  wgt	 = c(100, 92,135,144,140,101, 95,101, 98,105,
           108, 85,130,127,109,107,117,100,118,102),
  prot = c(14,15,18,12,15,15,14,17,15,14,
           17,19,19,20,15,16,18,13,18,14))

#Visualize the relationship between all the possible combinations in our data
#This provides a table as an output and you can see the strength of each relationship
corr.test(calorie, use = "pairwise", method = "pearson", adjust = "none", alpha = 0.05)
cor(calorie)

#View the same kind of pair-wise comparisons in graphical form
pairs(data = calorie, ~ age + carb + prot)

#Chart the correlations between each of the variables to look for trends
chart.Correlation(calorie, method = "pearson", histogram = TRUE, pch = 16)

#Fit multiple linear regression with all the variables
summary(lm.cal <- lm(wgt ~ age + carb + prot, data = calorie))

#There are two main appraoches that you can take to determining which variables
#or combination of variables are the best at explaining the variation in your data

#The first here uses the step function
#The step function can add or remove terms from a model
#Or use a process that both adds and removes them
#These step-wise procedure helps you refine your combinations until you find the best model
model.null = lm(wgt ~ 1, data = calorie)
model.full = lm(wgt ~ age + carb + prot, data = calorie)
step(model.null, scope = list(upper = model.full), direction = "both", data = calorie)  

model.final = lm(wgt ~ carb + prot, data = calorie)
summary(model.final)    
anova(model.final)
plot(model.final)

#This is the AIC approach that combines all combinations and does a whole-sale comparision
#Input each model combination
model.1  = lm(wgt ~ age,               data = calorie)
model.2  = lm(wgt ~ carb,              data = calorie)
model.3  = lm(wgt ~ prot,              data = calorie)
model.4  = lm(wgt ~ age + carb,        data = calorie)
model.5  = lm(wgt ~ age + prot,        data = calorie)
model.6  = lm(wgt ~ carb + prot,       data = calorie) 
model.7  = lm(wgt ~ age + carb + prot, data = calorie)

AIC(model.1, model.2, model.3, model.4, model.5, model.6, model.7)
summary(model.6)


#Run an AIC model to compare
compareLM(model.1, model.2, model.3, model.4, model.5, model.6,model.7)

#Remember that the lower the AIC score, the better the model is at explaining variation in the data ... 
#HOWEVER, REMEMBER that as you add variables to a model, you are automatically adding explanitory power, 
#so you have to balance the lowest AIC score AND the fewest number of variables

#You can also show the results graphically if this helps to visualize
Result = compareLM(model.1, model.2, model.3, model.4, model.5, model.6,model.7)
plot(Result$Fit.criteria$AICc, xlab = "Model number", ylab = "AICc")
lines(Result$Fit.criteria$AICc)

###Which model is the best??

#########################################################################################
####################  GENERALIZED LINEAR REGRESSION  ####################################
#########################################################################################

#Often our data do not follow the assumption that the error is normally distributed
#Therefore we have to "generalize" the data through transformations through "link" functions
#related to a specific probability distribution

#Create example data set of age and birthweight
age <- c(40, 38, 40, 35, 36, 37, 41, 40, 37, 38, 40, 38,
         40, 36, 40, 38, 42, 39, 40, 37, 36, 38, 39, 40)
birthw <- c(2968, 2795, 3163, 2925, 2625, 2847, 3292, 3473, 2628, 3176,
            3421, 2975, 3317, 2729, 2935, 2754, 3210, 2817, 3126, 2539,
            2412, 2991, 2875, 3231)
sex <- gl(2,12, labels=c("M","F"))

#Plot the data
plot(age, birthw, col=as.numeric(sex), pch=3*as.numeric(sex),
     main="Dobson's Birth Weight Data")
legend("topleft", levels(sex), col=1:2, pch=3*(1:2), bty="n")

hist(birthw)
hist(age)

shapiro.test(birthw)

#Analyze linear relationship between the variables
summary(l1 <- lm(birthw ~ sex + age))
anova(l1)

#We can normalized the data by assigning the normal distribution
summary(zi <- glm(birthw ~ sex + age, family=gaussian()))

##Are the model results different?


#Now create a data frame of count data for a Poisson Regression 
x <- c(-1,-1,0,0,0,0,1,1,1)
y <- c(2,3,6,7,8,9,10,12,15)
hist(y)
shapiro.test(y)

summary(glm(y~x, family=poisson(link="identity")))
summary(lm(y~x))

#Another Poisson regression example withhout the link function
counts <- c(22,2,10,16,54,115,19,33,73,11,17,28)
type <- gl(4,3,12,labels=c("freckle","superficial","nodular","indeterminate"))
site <- gl(3,1,12,labels=c("head/neck","trunk","extremities"))
data.frame(counts,type,site)
summary(glm(counts ~ type + site, family=poisson()))

#Create a dataframe to look at the binomial distribution with different link functions
dose <- c(1.6907, 1.7242, 1.7552, 1.7842, 1.8113, 1.8369, 1.861, 1.8839)
x <- c( 6, 13, 18, 28, 52, 53, 61, 60)
n <- c(59, 60, 62, 56, 63, 59, 62, 60)
dead <- cbind(x, n-x)

#How do the results change?
summary(glm(dead ~ dose, family=binomial(link=logit)))
summary(glm(dead ~ dose, family=binomial(link=probit)))
summary(glm(dead ~ dose, family=binomial(link=cloglog)))

#Tree example
data("trees")
head(trees)

shapiro.test(trees$Volume)

hist(trees$Volume)

tree.model <- glm(Volume ~ Height + Girth, data = trees, 
                  family = gaussian(link = "identity"))
summary(tree.model)

#Cars model
shapiro.test(mtcars$mpg)

model1 <- lm(mpg ~ cyl + wt,        data = mtcars)
model2 <- lm(mpg ~ wt,              data = mtcars)
model3 <- lm(mpg ~ cyl + wt + gear, data = mtcars)

AIC(model1, model2, model3)

summary(model1)
anova(model1)

plot(model1)
