###############################
#### Plotting with ggplot ####
###############################
install.packages("ggplot2")
library(ggplot2)

#All ggplot2 plots begin with a call to ggplot(), 
#supplying default data and aesthethic mappings, specified by aes() 
#You then add layers, scales, coords and facets with +

#For example, let's create a scatter plot of car mpg and wt
p <- ggplot(mtcars, aes(x = wt, y = mpg)) +   #If you just plot this line, it creates the plot but with no data
      #Add a point layer
      geom_point(size = 2) +                  #Here you can specify size, color, and type of point (or line, bar, etc.)
      #Add axis labels
      labs(x = "Car Weight") +
      labs(y = "Miles per Gallon") 

#We can remove the grey background by changing the theme
p +
  theme_bw()

#We can also remove the gridlines and add a border
p +
  theme_classic() +
  theme(panel.border = element_rect(fill = NA))     #"element" allows you to change components of the plot itself

#Increase the text size of the axis
p +
  theme_classic() +
  theme(panel.border = element_rect(fill = NA)) +
  theme(axis.text = element_text(size=14, color = "black"), axis.title = element_text(size=14))       

#We can also add a fitted line and ribbon
p +
  geom_smooth(method='lm', color = "black")  +      #Use fill = NA if you don't want the ribbon
  theme_classic() +
  theme(panel.border = element_rect(fill = NA)) +
  theme(axis.text = element_text(size=14, color = "black"), axis.title = element_text(size=14))       

#We can include special characters in axis labels by using the "expression" and "paste" functions
ggplot(mtcars, aes(x = wt, y = mpg)) +   
  geom_point(size = 2) +                  
  labs(x = "Car Weight (kg)") +
  labs(y = expression(paste("Mileage (miles", phantom(1), gal^-1,")"))) +          #phantom() adds a space
  geom_smooth(method='lm', color = "black")  +
  theme_classic() +
  theme(panel.border = element_rect(fill = NA)) +
  theme(axis.text = element_text(size=14, color = "black"), axis.title = element_text(size=14)) 

#We can use the facet_wrap function to plot by grouping variable
ggplot(mtcars, aes(x = wt, y = mpg)) +   
  geom_point(size = 2) +       
  facet_wrap(~ cyl) + 
  labs(x = "Car Weight (kg)") +
  labs(y = expression(paste("Mileage (miles", phantom(1), gal^-1,")"))) +          #phantom() adds a space
  theme_classic() +
  theme(panel.border = element_rect(fill = NA)) +
  theme(axis.text = element_text(size=14, color = "black"), axis.title = element_text(size=14)) 

#We can create a bar plot by using geom_bar
ggplot(mtcars, aes(x = as.factor(cyl), y = mpg)) +  #Need as.factor or else treats the x-axis labels as numeric
  geom_bar(stat='identity') +
  theme_bw() +
  labs(x = "Cylinder") +
  labs(y = expression(paste("Mileage (miles", phantom(1), gal^-1,")")))
  
#We can flip it to make a horizontal graph
ggplot(mtcars, aes(x = as.factor(cyl), y = mpg)) +  
  geom_bar(stat='identity') +
  coord_flip() +
  theme_bw() +
  labs(x = "Cylinder") +
  labs(y = expression(paste("Mileage (miles", phantom(1), gal^-1,")")))

#We can also change the labels on either axis
labels = c("Four", "Six", "Eight")
ggplot(mtcars, aes(x = as.factor(cyl), y = mpg)) +  
  geom_bar(stat='identity') +
  coord_flip() +
  theme_bw() +
  labs(x = "Cylinder") +
  labs(y = expression(paste("Mileage (miles", phantom(1), gal^-1,")"))) +
  scale_x_discrete(labels = labels) 

#We can use geom_raster to create a surface plot
data("faithfuld")
ggplot(faithfuld, aes(x = waiting, y = eruptions)) +
  geom_raster(aes(fill = density),    #The fill object will be the surface variable
             interpolate = TRUE)      #interpolate smooths the raster

#Adding legends can be a little trickier in ggplot
ggplot(faithfuld, aes(x = waiting, y = eruptions)) +
  geom_raster(aes(fill = density), interpolate = TRUE) +
  scale_fill_continuous(name="Density")     #For other types of plots, it may instead be scale_fill_discrete


